%global momorel 2

%define	_root_sbindir	/sbin
%define	_root_libdir	/%{_lib}

Summary: Utilities for managing ext2, ext3, and ext4 filesystems
Name: e2fsprogs
Version: 1.41.4
Release: %{momorel}m%{?dist}
# License based on upstream-modified COPYING file,
# which clearly states "V2" intent.
License: GPL
Group: System Environment/Base
Source0:  http://dl.sourceforge.net/sourceforge/%{name}/%{name}-%{version}.tar.gz
NoSource: 0
Source1: ext2_types-wrapper.h
Source2: blkid_types-wrapper.h
Source3: uuidd.init
Patch1: e2fsprogs-1.38-etcblkid.patch
Patch2: e2fsprogs-1.40.4-sb_feature_check_ignore.patch
Patch3: e2fsprogs-1.41.4-debugfs-stat-segfault.patch
Patch4: e2fsprogs-1.41.4-libext2fs-info.patch
Patch5: e2fsprogs-1.41.4-fix-blkid-segfault.patch
Patch6: e2fsprogs-1.41.4-ignore-NEEDS_RECOVERY-mismatch.patch
Patch7: e2fsprogs-1.41.4-ext4-resize-fixes.patch 
Patch8: e2fsprogs-1.41.4-fix-external-journals.patch
Patch9: e2fsprogs-1.41.4-i_file_acl_high-fix.patch
Patch10: e2fsprogs-1.41.4-minimum-resize.patch
Patch11: e2fsprogs-1.41.4-update-sb-journal-backup.patch
Patch12: e2fsprogs-1.41.4-extent-open-leak.patch

Url: http://e2fsprogs.sourceforge.net/
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
Requires: e2fsprogs-libs = %{version}-%{release}, device-mapper
Obsoletes: e4fsprogs
BuildRequires: pkgconfig, texinfo, libselinux-devel
BuildRequires: libsepol-devel, device-mapper-devel, util-linux

%description
The e2fsprogs package contains a number of utilities for creating,
checking, modifying, and correcting any inconsistencies in second,
third and fourth extended (ext2/ext3/ext4) filesystems. E2fsprogs
contains e2fsck (used to repair filesystem inconsistencies after an
unclean shutdown), mke2fs (used to initialize a partition to contain
an empty ext2 filesystem), debugfs (used to examine the internal
structure of a filesystem, to manually repair a corrupted
filesystem, or to create test cases for e2fsck), tune2fs (used to
modify filesystem parameters), and most of the other core ext2fs
filesystem utilities.

You should install the e2fsprogs package if you need to manage the
performance of an ext2, ext3, or ext4 filesystem.

%package libs
Summary: Ext2/3/4 filesystem-specific shared libraries and headers
Group: Development/Libraries
# License based on upstream-modified COPYING file,
# which clearly states "V2" intent as well as other
# licenses for various libs, which also have in-source specification.
License: GPLv2 and LGPLv2 and BSD and MIT
Requires(post): glibc

%description libs
E2fsprogs-lib contains the libraries of the e2fsprogs package.

%package devel
Summary: Ext2/3/4 filesystem-specific static libraries and headers
Group: Development/Libraries
# License based on upstream-modified COPYING file,
# which clearly states [L]GPLv2 intent as well as other
# licenses for various libs, which also have in-source specification.
License: GPLv2 and LGPLv2 and BSD and MIT
Requires: e2fsprogs-libs = %{version}-%{release}
Requires: device-mapper-devel >= 1.02.02-3
Requires: gawk
Requires(post): info
Requires(preun): info

%description devel
E2fsprogs-devel contains the libraries and header files needed to
develop second, third and fourth extended (ext2/ext3/ext4)
filesystem-specific programs.

You should install e2fsprogs-devel if you want to develop ext2/3/4
filesystem-specific programs. If you install e2fsprogs-devel, you'll
also want to install e2fsprogs.

%package -n uuidd
Summary: helper daemon to guarantee uniqueness of time-based UUIDs
Group: System Environment/Daemons
Requires: e2fsprogs-libs = %{version}-%{release}
License: GPLv2
Requires(pre): shadow-utils

%description -n uuidd
The uuidd package contains a userspace daemon (uuidd) which guarantees
uniqueness of time-based UUID generation even at very high rates on
SMP systems.

%prep
%setup -q -n e2fsprogs-%{version}
# put blkid.tab in /etc/blkid/
%patch1 -p1 -b .etcblkid
# ignore some flag differences on primary/backup sb feature checks
# mildly unsafe but 'til I get something better, avoid full fsck
# after an selinux install...
%patch2 -p1 -b .featurecheck
# Fix segfault in debugfs "stat" if fs not open
%patch3 -p1 -b .statfs
# Fix up name of info file
%patch4 -p1 -b .info
# Fix blkid segfault in modules.dep scanning
%patch5 -p1 -b .info
# Ignore NEEDS_RECOVERY mismatch
%patch6 -p1 -b .recovery
# Fix ext4 resize issues
%patch7 -p1 -b .resize
# Fix external journals
%patch8 -p1 -b .ext-journal
# e2fsck: On a 32-bit filesystem, make sure i_file_acl_high is zero
%patch9 -p1 -b .acl_hi
# Fix minimum resize calculation and enforce it
%patch10 -p1 -b .resize_min
# Update sb journal backup blocks on resize
%patch11 -p1 -b .resize_sb_backup
# Fix memory leak in extent handling
%patch12 -p1 -b .extent_leak

%build
autoreconf -if
%configure --enable-elf-shlibs --enable-nls --disable-e2initrd-helper  --enable-blkid-devmapper --enable-blkid-selinux
make %{?_smp_mflags}

%install
rm -rf %{buildroot}
export PATH=/sbin:$PATH
make install install-libs DESTDIR=%{buildroot} INSTALL="%{__install} -p" \
	root_sbindir=%{_root_sbindir} root_libdir=%{_root_libdir}

# ugly hack to allow parallel install of 32-bit and 64-bit -devel packages:
%define multilib_arches %{ix86} x86_64 ppc ppc64 s390 s390x sparcv9 sparc64

%ifarch %{multilib_arches}
mv -f %{buildroot}%{_includedir}/ext2fs/ext2_types.h \
      %{buildroot}%{_includedir}/ext2fs/ext2_types-%{_arch}.h
install -p -m 644 %{SOURCE1} %{buildroot}%{_includedir}/ext2fs/ext2_types.h

mv -f %{buildroot}%{_includedir}/blkid/blkid_types.h \
      %{buildroot}%{_includedir}/blkid/blkid_types-%{_arch}.h
install -p -m 644 %{SOURCE2} %{buildroot}%{_includedir}/blkid/blkid_types.h
%endif

# It fails when arch is i686.
sed -i 's/blkid_types-i386.h/blkid_types-i686.h/g' %{buildroot}%{_includedir}/blkid/blkid_types.h
sed -i 's/ext2_types-i386.h/ext2_types-i686.h/g' %{buildroot}%{_includedir}/ext2fs/ext2_types.h

# Our own initscript for uuidd
install -D -m 755 %{SOURCE3}  %{buildroot}/etc/init.d/uuidd
# And a dir uuidd needs that the makefiles don't create
install -d  %{buildroot}/var/lib/libuuid

%find_lang %{name}

%check
make check

%clean
rm -rf %{buildroot}

%post
[ -e /etc/blkid.tab ] && mv /etc/blkid.tab /etc/blkid/blkid.tab || :
[ -e /etc/blkid.tab.old ] && mv /etc/blkid.tab.old /etc/blkid/blkid.tab.old || :

%post libs -p /sbin/ldconfig

%postun libs -p /sbin/ldconfig

%post devel
if [ -x /sbin/install-info ]; then
    /sbin/install-info %{_infodir}/libext2fs.info %{_infodir}/dir
fi
exit 0

%postun devel
if [ $1 = 0 ]; then
   /sbin/install-info --delete %{_infodir}/libext2fs.info %{_infodir}/dir
fi
exit 0

%pre -n uuidd
getent group uuidd >/dev/null || groupadd -r uuidd
getent passwd uuidd >/dev/null || \
useradd -r -g uuidd -d /var/lib/libuuid -s /sbin/nologin \
    -c "UUID generator helper daemon" uuidd
exit 0

%post -n uuidd
/sbin/chkconfig --add uuidd
/sbin/chkconfig uuidd off

%preun -n uuidd
if [ "$1" = 0 ]
then
	/sbin/service uuidd stop > /dev/null 2>&1 || :
	/sbin/chkconfig --del uuidd
fi

%files -f %{name}.lang
%defattr(-,root,root)
%doc README RELEASE-NOTES

%dir /etc/blkid
%config(noreplace) /etc/mke2fs.conf
%{_root_sbindir}/badblocks
%{_root_sbindir}/blkid
%{_root_sbindir}/debugfs
%{_root_sbindir}/dumpe2fs
%{_root_sbindir}/e2fsck
%{_root_sbindir}/e2image
%{_root_sbindir}/e2label
%{_root_sbindir}/e2undo
%{_root_sbindir}/findfs
%{_root_sbindir}/fsck
%{_root_sbindir}/fsck.ext2
%{_root_sbindir}/fsck.ext3
%{_root_sbindir}/fsck.ext4
%{_root_sbindir}/fsck.ext4dev
%{_root_sbindir}/logsave
%{_root_sbindir}/mke2fs
%{_root_sbindir}/mkfs.ext2
%{_root_sbindir}/mkfs.ext3
%{_root_sbindir}/mkfs.ext4
%{_root_sbindir}/mkfs.ext4dev
%{_root_sbindir}/resize2fs
%{_root_sbindir}/tune2fs
%{_sbindir}/filefrag
%{_sbindir}/mklost+found

%{_bindir}/chattr
%{_bindir}/lsattr
%{_bindir}/uuidgen
%{_mandir}/man1/chattr.1*
%{_mandir}/man1/lsattr.1*
%{_mandir}/man1/uuidgen.1*

%{_mandir}/man5/e2fsck.conf.5*
%{_mandir}/man5/mke2fs.conf.5*

%{_mandir}/man8/badblocks.8*
%{_mandir}/man8/blkid.8*
%{_mandir}/man8/debugfs.8*
%{_mandir}/man8/dumpe2fs.8*
%{_mandir}/man8/e2fsck.8*
%{_mandir}/man8/findfs.8*
%{_mandir}/man8/filefrag.8*
%{_mandir}/man8/fsck.ext2.8*
%{_mandir}/man8/fsck.ext3.8*
%{_mandir}/man8/fsck.ext4.8*
%{_mandir}/man8/fsck.ext4dev.8*
%{_mandir}/man8/e2image.8*
%{_mandir}/man8/e2label.8*
%{_mandir}/man8/e2undo.8*
%{_mandir}/man8/fsck.8*
%{_mandir}/man8/logsave.8*
%{_mandir}/man8/mke2fs.8*
%{_mandir}/man8/mkfs.ext2.8*
%{_mandir}/man8/mkfs.ext3.8*
%{_mandir}/man8/mkfs.ext4.8*
%{_mandir}/man8/mkfs.ext4dev.8*
%{_mandir}/man8/mklost+found.8*
%{_mandir}/man8/resize2fs.8*
%{_mandir}/man8/tune2fs.8*

%files libs
%defattr(-,root,root)
%{_root_libdir}/libblkid.so.*
%{_root_libdir}/libcom_err.so.*
%{_root_libdir}/libe2p.so.*
%{_root_libdir}/libext2fs.so.*
%{_root_libdir}/libss.so.*
%{_root_libdir}/libuuid.so.*

%files devel
%defattr(-,root,root)
%{_infodir}/libext2fs.info*
%{_bindir}/compile_et
%{_bindir}/mk_cmds

%{_libdir}/libblkid.a
%{_libdir}/libblkid.so
%{_libdir}/libcom_err.a
%{_libdir}/libcom_err.so
%{_libdir}/libe2p.a
%{_libdir}/libe2p.so
%{_libdir}/libext2fs.a
%{_libdir}/libext2fs.so
%{_libdir}/libss.a
%{_libdir}/libss.so
%{_libdir}/libuuid.a
%{_libdir}/libuuid.so
%{_libdir}/pkgconfig/*.pc

%{_datadir}/et
%{_datadir}/ss
%{_includedir}/blkid
%{_includedir}/e2p
%{_includedir}/et
%{_includedir}/ext2fs
%{_includedir}/ss
%{_includedir}/uuid
%{_mandir}/man1/compile_et.1*
%{_mandir}/man1/mk_cmds.1*
%{_mandir}/man3/com_err.3*
%{_mandir}/man3/libblkid.3*
%{_mandir}/man3/uuid.3*
%{_mandir}/man3/uuid_clear.3*
%{_mandir}/man3/uuid_compare.3*
%{_mandir}/man3/uuid_copy.3*
%{_mandir}/man3/uuid_generate.3*
%{_mandir}/man3/uuid_generate_random.3*
%{_mandir}/man3/uuid_generate_time.3*
%{_mandir}/man3/uuid_is_null.3*
%{_mandir}/man3/uuid_parse.3*
%{_mandir}/man3/uuid_time.3*
%{_mandir}/man3/uuid_unparse.3*

%files -n uuidd
%defattr(-,root,root)
%{_sysconfdir}/init.d/uuidd
%{_mandir}/man8/uuidd.8*
%attr(-, uuidd, uuidd) %{_sbindir}/uuidd
%dir %attr(2775, uuidd, uuidd) /var/lib/libuuid

%changelog
* Tue Jun 23 2009 Yohsuke Ooi <meke@momonga-linux.org> 
- (1.41.4-2m)
- import fedora patches.
-- fix resize2fs broken ext4-resize 

* Thu Jun 18 2009 Masahiro Takahata <takahata@momonga-linux.org>
- (1.41.4-1m)
- sync Fedora 11 release version
- rollback oldversion

* Mon Jun  1 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (1.41.6-2m)
- fix install-info

* Mon Jun  1 2009 Yohsuke Ooi <meke@momonga-linux.org> 
- (1.41.6-1m)
- update 1.41.6

* Sun Apr 26 2009 Yohsuke Ooi <meke@momonga-linux.org> 
- (1.41.5-1m)
- update 1.41.5

* Wed Jan 21 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (1.41.3-4m)
- rebuild against rpm-4.6

* Thu Jan 15 2009 Yohsuke Ooi <meke@momonga-linux.org> 
- (1.41.3-3m)
- blkid support btrfs.

* Tue Dec 16 2008 TABUCHI Takaaki <tab@momonga-linux.org>
- (1.41.3-2m)
- sync with fedora spec

* Tue Oct 21 2008 Yohsuke Ooi <meke@momonga-linux.org> 
- (1.41.3-1m)
- update 1.41.3

* Fri Jul 11 2008 Yohsuke Ooi <meke@momonga-linux.org>
- (1.41.0-1m)
- update 1.41.0

* Sat Jul  5 2008 Yohsuke Ooi <meke@momonga-linux.org>
- (1.40.11-1m)
- update 1.40.11

* Sat May 31 2008 Yohsuke Ooi <meke@momonga-linux.org>
- (1.40.10-1m)
- update 1.40.10

* Sat May 17 2008 Yohsuke Ooi <meke@momonga-linux.org>
- (1.40.8-2m)
- import fedora patches

* Sat May 10 2008 Yohsuke Ooi <meke@momonga-linux.org>
- (1.40.8-1m)
- update 1.40.8

* Thu Apr 03 2008 TABUCHI Takaaki <tab@momonga-linux.org>
- (1.40.6-2m)
- rebuild against gcc43

* Tue Feb 12 2008 Yohsuke Ooi <meke@momonga-linux.org>
- (1.40.6-1m)
- update 1.40.6

* Fri Dec 28 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (1.40.2-3m)
- fails when arch is i686

* Mon Dec 24 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (1.40.2-2m)
- fails when arch is i686

* Mon Dec 10 2007 NARITA Koichi <pulsar@momonga-linux.org>
- (1.40.2-1m)
- [SECURITY] CVE-2007-5497
- update to 1.40.2 and almost sync with Fedora devel
- clean up repository

* Mon Nov 20 2006 TABUCHI Takaaki <tab@momonga-linux.org>
- (1.39-3m)
- - sync with 1.39-7 from fc-devel
- - rename patch40 to patch140
- - add patch40 .. patch60
- - add Obsoletes: ext2resize
- - changelog is below
-* Wed Sep 20 2006 Jarod Wilson <jwilson@redhat.com> - 1.39-7
-- 32-bit 16T fixups from esandeen (#202807)
-- Update summaries and descriptions
-
-* Sun Sep 17 2006 Karel Zak <kzak@redhat.com> - 1.39-6
-- Fix problem with empty FAT label (#206656)
-
-* Tue Sep  5 2006 Peter Jones <pjones@redhat.com> - 1.39-5
-- Fix memory leak in device probing.

* Mon Oct  9 2006 Nishio Futoshi <futoshi@momonga-linux.org>
- (1.39-2m)
- add patch40 (for mkinstalldirs)

* Sun Jul 30 2006 TABUCHI Takaaki <tab@momonga-linux.org>
- (1.39-1m)
- update to 1.39
  - sync with 1.39-4 from fc-devel

* Sun May 14 2006 Masahiro Takahata <takahata@momonga-linux.org>
- (1.38-2m)
- modify for 64 bit arch

* Sun May  7 2006 TABUCHI Takaaki <tab@momonga-linux.org>
- (1.38-1m)
- version up based on Fedora (1.38-12)
-  Wed Mar  8 2006 Peter Jones <pjones@redhat.com> - 1.38-12
- - Move /etc/blkid.tab to /etc/blkid/blkid.tab
- 
- * Tue Mar  7 2006 David Cantrell <dcantrell@redhat.com> - 1.38-11
- - BuildRequires pkgconfig
- 
- * Tue Mar  7 2006 David Cantrell <dcantrell@redhat.com> - 1.38-10
- - Disable /etc/blkid.tab caching if time is set before epoch (#182188)
- 
- * Fri Feb 24 2006 Peter Jones <pjones@redhat.com> - 1.38-9
- - _don't_ handle selinux context on blkid.tab, dwalsh says this is a no-no.
- #'
- * Wed Feb 22 2006 Peter Jones <pjones@redhat.com> - 1.38-8
- - handle selinux context on blkid.tab
- 
- * Mon Feb 20 2006 Karsten Hopp <karsten@redhat.de> 1.38-7
- - BuildRequires: gettext-devel
- 
- * Fri Feb 10 2006 Jesse Keating <jkeating@redhat.com> - 1.38-6.2
- - bump again for double-long bug on ppc(64)
- 
- * Tue Feb  7 2006 Jesse Keating <jkeating@redhat.com> - 1.38-6.1
- - rebuilt for new gcc4.1 snapshot and glibc changes
- 
- * Wed Jan 11 2006 Karel Zak <kzak@redhat.com> 1.38-6
- - cleanup device-mapper patch
- - use pkg-config for device-mapper
- 
- * Mon Jan  9 2006 Peter Jones <pjones@redhat.com> 1.38-5
- - fix some more minor logic errors in dm probing
- 
- * Wed Jan  4 2006 Peter Jones <pjones@redhat.com> 1.38-4
- - fix a logic error in dm probing
- - add priority group for dm devices, so they'll be preferred
- #'
- * Tue Jan  3 2006 Peter Jones <pjones@redhat.com> 1.38-3
- - added support for device-mapper devices
- 
- * Fri Dec  9 2005 Jesse Keating <jkeating@redhat.com>
- - rebuilt
- 
- * Thu Nov 10 2005 Thomas Woerner <twoerner@redhat.com> 1.38-2.1
- - fixed file conflicts between 32bit and 64bit packages (#168815)
- - fixed mklost+found crashes with buffer overflow (#157773)
-   Thanks to Arjan van de Ven for the patch
- 
- * Wed Nov  9 2005 Thomas Woerner <twoerner@redhat.com> 1.38-2
- - splitted up libs from main package, into a new e2fsprogs-libs package
- - fixed requires and prereqs
- 
- * Thu Sep  8 2005 Thomas Woerner <twoerner@redhat.com> 1.38-1
- - new version 1.38
- - Close File descriptor for unregognized devices (#159878)
-   Thanks to David Milburn for the patch.
-   Merged from RHEL-4
- - enable tune2fs to set and clear feature resize_inode (#167816)
- - removed outdated information from ext2online man page (#164383)

* Wed Jan  4 2006 YAMAZAKI Makoto <zaki@zakky.org>
- (1.37-2m)
- set svn:eol-style property to
   e2fsprogs-1.1589.patch
   e2fsprogs-1.1590.patch
   e2fsprogs-1.1591.patch

* Sun May 22 2005 Hiroyuki Koga <kuma@momonga-linux.org>
- (1.37-1m)
- version up based on Fedora (1.37-4)

  * Tue May 10 2005 Jeremy Katz <katzj@redhat.com> - 1.37-4
  - added libblkid.so to devel package

  * Wed May  4 2005 Jeremy Katz <katzj@redhat.com> - 1.37-3
  - fix cramfs detection bug in libblkid

  * Fri Apr  8 2005 Thomas Woerner <twoerner@redhat.com> 1.37-2
  - upstream fixes 1.1589, 1.1590 and 1.1591:
  - add include of stdlib.h to fix a core dump bug on IA64
  - ignore environment variables in blkid and ext2fs for setuid and setguid
    programs
  - no LOW_DTIME checks if the superblock last mount time looks insane

  * Fri Apr  8 2005 Thomas Woerner <twoerner@redhat.com> 1.37-1
  - new version 1.37
  - dropped upstream merged getsize-wrap patch

  * Wed Mar 16 2005 Stephen C. Tweedie <sct@redhat.com> 1.36-1.4
  - Fix the getsize-wrap patch for >4TB filesystems

  * Mon Feb 21 2005 Stephen C. Tweedie <sct@redhat.com> 1.36-1.2
  - Re-enable resize2fs
  - Add bigendian byte-swapping fix when growing the gdt table

  * Fri Feb 11 2005 Stephen C. Tweedie <sct@redhat.com> 1.36-1.1
  - Fix for >=4TB devices

* Tue Jan 25 2005 TABUCHI Takaaki <tab@momonga-linux.org>
- (1.35-2m)
- merge FC3 (1.35-11.2)

* Thu Sep 30 2004 YAMAZAKI Makoto <zaki@zakky.org>
- (1.35-2m)
- use %%{_lib} instead of lib

* Wed Mar 17 2004 YAMAZAKI Makoto <zaki@zakky.org>
- (1.35-1m)
- update to 1.35

* Wed Mar 17 2004 Toru Hoshina <t@momonga-linux.org>
- (1.34-2m)
- revised spec for enabling rpm 4.2.

* Mon Aug 25 2003 Masahiro Takahata <takahata@momonga-linux.org>
- (1.34-1m)
- update to 1.34

* Mon Mar 17 2003 KOMATSU Shinichiro <koma2@momonga-linux.org>
- (1.32-1m)
- update to 1.32
- unapply e2fsprogs-1.19-mountlabel3.patch
  (I am not sure whether it is still needed). 
- use * and macros in %%files section
- add more documents

* Wed Oct 30 2002 KOMATSU Shinichiro <koma2@jiro.c.u-tokyo.ac.jp>
- (1.29-1m)
- update to 1.29
- s/telia/us/

* Tue Apr 30 2002 Kenta MURATA <muraken@kondara.org>
- (1.27-6k)
- omit /sbin/ldconfig in PreReq.
- /sbin/install-info -> info in PreReq.

* Mon Apr  8 2002 Toru Hoshina <t@@kondara.org>
- (1.27-4k)
- a couple of commands lost.

* Wed Mar 20 2002 Tsutomu Yasuda <tom@kondara.org>
- (1.27-2k)
- update to 1.27

* Fri May  4 2001 YAMAGUCHI Kenji <yamk@kondara.org>
- (1.19-8k)
- merged RedHat esfsprogs-1.19-4.src.rpm patches for mountlabel.
- append URL:
- %{_tmppath}

* Wed Oct 25 2000 MATSUDA, Daiki <dyky@df-usa.com>
- modifiled %post and %preun section from .gz to .bz2

* Tue Aug 30 2000 Kazuhiko <kazuhiko@kondara.org>
- version 1.19
- remove e2fsprogs-debugfsy2k.patch
- add fsck.ext3, resize2fs, resize2fs.8*

* Sat Jul  8 2000 Toru Hoshina <t@kondara.org>
- rebuild against glibc-2.1.90, X-4.0, rpm-3.0.5.

* Sat Jun  3 2000 MATSUDA, Daiki <dyky@df-usa.com>
- uncheck fsck.reiserfs

* Sun Apr 02 2000 Takaaki Tabuchi <tab@kondara.org>
- merge redhat6.2(Release 5)
- add patch, Prereq, post devel , postun devel.

* Wed Mar 1 2000 Masako Hattori <maru@kondara.org>
- change jman mv->cp

* Wed Feb 23 2000 Masako Hattori <maru@kondara.org>
- do not shake %{_mandir}/ja

* Sat Feb  5 2000 Bill Nottingham <notting@redhat.com>
- add install-info scripts

* Thu Feb 03 2000 Elliot Lee <sopwith@redhat.com>
- Fix bug #8585 (Y2K problems in debugfs)

* Wed Feb 02 2000 Jakub Jelinek <jakub@redhat.com>
- allow multiline errors in et, so that other programs
  can use compile_et (from Kerberos)

* Tue Feb 1 2000 Masako Hattori <maru@kondara.org>
- add man-pages-ja-e2fsprogs-20000115

* Thu Jan 13 2000 Jeff Johnson <jbj@redhat.com>
- build 1.18 for 6.2.

* Sun Nov 28 1999 Masako Hattori <maru@kondara.org>
- add man-pages-ja-e2fsprogs-19991115

* Thu Nov 18 1999 Norihito Ohmori <nono@kondara.org>
- be a NoSrc :-P

* Tue Oct 26 1999 Bill Nottingham <notting@redhat.com>
- update to 1.17

* Mon Oct 25 1999 Bill Nottingham <notting@redhat.com>
- update to 1.16

* Thu Oct 21 1999 Bill Nottingham <notting@redhat.com>
- add patch to fix SIGUSR1 kills.

* Mon Oct 04 1999 Cristian Gafton <gafton@redhat.com>
- rebuild against new glibc in the sparc tree

* Thu Sep 23 1999 Jakub Jelinek <jakub@redhat.com>
- update mke2fs man page so that it reflects changes in mke2fs
  netweem 1.14 and 1.15

* Thu Aug  5 1999 Bill Nottingham <notting@redhat.com>
- fix lsattr on alpha

* Thu Jul 29 1999 Jeff Johnson <jbj@redhat.com>
- update to 1.15.

* Sun Mar 21 1999 Cristian Gafton <gafton@redhat.com> 
- auto rebuild in the new build environment (release 4)

* Tue Mar 16 1999 Cristian Gafton <gafton@redhat.com>
- fix fsck segfault

* Tue Feb  2 1999 Jeff Johnson <jbj@redhat.com>
- update to 1.14
- use %configure to generate config.sub on arm

* Thu Jan 14 1999 Jeff Johnson <jbj@redhat.com>
- fix /usr/bin/compile_et and doco for com_err.h (#673)

* Thu Jan 07 1999 Cristian Gafton <gafton@redhat.com>
- build with prefix=/usr
- add arm patch

* Mon Dec 28 1998 Jeff Johnson  <jbj@redhat.com>
- update to 1.13.

* Fri Aug 28 1998 Jeff Johnson <jbj@redhat.com>
- recompile statically linked binary for 5.2/sparc

* Mon Jul 13 1998 Jeff Johnson <jbj@redhat.com>
- upgrade to 1.12.

* Thu May 07 1998 Prospector System <bugs@redhat.com>
- translations modified for de, fr, tr

* Thu Apr 30 1998 Cristian Gafton <gafton@redhat.com>
- include <asm/types.h> to match kernel types in utils

* Tue Oct 14 1997 Donnie Barnes <djb@redhat.com>
- spec file cleanups

* Wed Oct 01 1997 Erik Troan <ewt@redhat.com>
- fixed broken llseek() prototype 

* Wed Aug 20 1997 Erik Troan <ewt@redhat.com>
- added patch to prototype llseek

* Tue Jun 17 1997 Erik Troan <ewt@redhat.com>
- built against glibc
